@@ -21,7 +21,7 @@ use tokio::io::{AsyncReadExt, BufReader};
 pub use http::response::Parts;
 
 use super::errors::*;
-use super::header::{self, HeaderMap, HeaderValue, InvalidHeaderValue, CONTENT_ENCODING, SET_COOKIE};
+use super::header::{self, HeaderMap, HeaderValue, InvalidHeaderValue, CONTENT_ENCODING};
 use crate::http::StatusCode;
 
 /// Response body type.
@@ -122,16 +122,6 @@ impl From<hyper::Body> for Body {
     }
 }
 
-/// Control response flow.
-#[derive(Clone, Copy, Eq, PartialEq, PartialOrd, Ord, Debug)]
-pub enum FlowState {
-    /// Default value.
-    Capturing = 0,
-    /// Skip next middlewares and handler, start to execute after middlewares.
-    Bubbling,
-    /// Skip next middlewares and handler.
-    Commited,
-}
 /// Represents an HTTP response
 pub struct Response {
     status_code: Option<StatusCode>,
@@ -140,7 +130,6 @@ pub struct Response {
     version: Version,
     pub(crate) cookies: CookieJar,
     pub(crate) body: Option<Body>,
-    flow_state: FlowState,
 }
 impl Default for Response {
     fn default() -> Self {
@@ -182,7 +171,6 @@ impl From<hyper::Response<hyper::Body>> for Response {
             version,
             headers,
             cookies,
-            flow_state: FlowState::Capturing,
         }
     }
 }
@@ -196,7 +184,6 @@ impl Response {
             version: Version::default(),
             headers: HeaderMap::new(),
             cookies: CookieJar::new(),
-            flow_state: FlowState::Capturing,
         }
     }
 
@@ -360,11 +347,7 @@ impl Response {
     /// Set status code.
     #[inline]
     pub fn set_status_code(&mut self, code: StatusCode) {
-        let is_success = code.is_success();
         self.status_code = Some(code);
-        if !is_success {
-            self.set_flow_state(FlowState::Bubbling);
-        }
     }
 
     /// Get content type.
@@ -386,7 +369,6 @@ impl Response {
     pub fn set_http_error(&mut self, err: HttpError) {
         self.status_code = Some(err.code);
         self.http_error = Some(err);
-        self.set_flow_state(FlowState::Bubbling);
     }
 
     /// Render serializable data as json content. It will set ```content-type``` to ```application/json; charset=utf-8```.
@@ -488,7 +470,6 @@ impl Response {
             self.headers.insert(header::CONTENT_TYPE, "text/html".parse().unwrap());
         }
         self.headers.insert(header::LOCATION, url.as_ref().parse().unwrap());
-        self.set_flow_state(FlowState::Bubbling);
     }
     /// Redirect found.
     #[inline]
@@ -499,7 +480,6 @@ impl Response {
                 .insert(header::CONTENT_TYPE, HeaderValue::from_static("text/html"));
         }
         self.headers.insert(header::LOCATION, url.as_ref().parse().unwrap());
-        self.set_flow_state(FlowState::Bubbling);
     }
     /// Redirect other.
     #[inline]
@@ -510,35 +490,8 @@ impl Response {
                 .insert(header::CONTENT_TYPE, HeaderValue::from_static("text/html"));
         }
         self.headers.insert(header::LOCATION, url.as_ref().parse()?);
-        self.set_flow_state(FlowState::Bubbling);
         Ok(())
     }
-
-    /// Check is response is committed.
-    #[inline]
-    pub fn flow_state(&self) -> FlowState {
-        self.flow_state
-    }
-    /// Salvo executes before handler and path handler in sequence, when the response is in a
-    /// committed state, subsequent handlers will not be executed, and then all after
-    /// handlers will be executed.
-    ///
-    /// This is a sign that the http request is completed, which can be used to process early
-    /// return verification logic, such as permission verification, etc.
-    #[inline]
-    pub fn set_flow_state(&mut self, flow_state: FlowState) -> bool {
-        if self.flow_state < flow_state {
-            for cookie in self.cookies.delta() {
-                if let Ok(hv) = cookie.encoded().to_string().parse() {
-                    self.headers.append(SET_COOKIE, hv);
-                }
-            }
-            self.flow_state = flow_state;
-            true
-        } else {
-            false
-        }
-    }
 }
 
 impl Debug for Response {
@@ -635,7 +588,6 @@ mod test {
         // assert_eq!(response.header_cookies().len(), 1);
         response.cookies_mut().add(Cookie::new("money", "sh*t"));
         assert_eq!(response.cookies().get("money").unwrap().value(), "sh*t");
-        response.set_flow_state(FlowState::Commited);
         // assert_eq!(response.header_cookies().len(), 2);
         assert_eq!(response.take_bytes().await.unwrap().len(), b"response body".len());
 
