@@ -7,14 +7,16 @@
 #![forbid(unsafe_code)]
 #![warn(missing_docs)]
 
+pub mod addr;
 pub mod catcher;
 mod depot;
 mod error;
 pub mod fs;
 mod handler;
 pub mod http;
+pub mod listener;
 pub mod routing;
-pub mod server;
+mod server;
 mod service;
 mod transport;
 pub mod writer;
@@ -28,12 +30,13 @@ pub use self::depot::Depot;
 pub use self::error::Error;
 pub use self::handler::Handler;
 pub use self::http::{Request, Response};
-pub use self::routing::Router;
-#[cfg(feature = "tls")]
-pub use self::server::TlsListener;
+#[cfg(feature = "rustls")]
+pub use self::listener::RustlsListener;
 #[cfg(unix)]
-pub use self::server::UnixListener;
-pub use self::server::{JoinedListener, Server, TcpListener};
+pub use self::listener::UnixListener;
+pub use self::listener::{JoinedListener, Listener, TcpListener};
+pub use self::routing::Router;
+pub use self::server::Server;
 pub use self::service::Service;
 pub use self::writer::Writer;
 pub use async_trait::async_trait;
@@ -46,12 +49,13 @@ pub mod prelude {
     pub use crate::depot::Depot;
     pub use crate::http::errors::*;
     pub use crate::http::{Request, Response, StatusCode};
-    pub use crate::routing::{filter, Router};
-    #[cfg(feature = "tls")]
-    pub use crate::server::TlsListener;
+    #[cfg(feature = "rustls")]
+    pub use crate::listener::RustlsListener;
     #[cfg(unix)]
-    pub use crate::server::UnixListener;
-    pub use crate::server::{JoinedListener, Server, TcpListener};
+    pub use crate::listener::UnixListener;
+    pub use crate::listener::{JoinedListener, Listener, TcpListener};
+    pub use crate::routing::{filter, Router};
+    pub use crate::server::Server;
     pub use crate::service::Service;
     pub use crate::writer::*;
     pub use crate::Handler;
@@ -72,7 +76,7 @@ fn new_runtime(threads: usize) -> Runtime {
 }
 
 /// If you don't want to include tokio in your project directly,
-/// you can use this function to start server.
+/// you can use this function to run server.
 /// ```ignore
 /// use salvo_core::prelude::*;
 /// #[fn_handler]
@@ -81,17 +85,17 @@ fn new_runtime(threads: usize) -> Runtime {
 /// }
 /// fn main() {
 ///
-///    let service = Service::new(Router::new().get(hello_world));
-///    let server = Server::bind(&"127.0.0.1:7878".parse().unwrap()).serve(service);
-///    salvo_core::start(server);
+///    let router = Router::new().get(hello_world);
+///    let server = Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router);
+///    salvo_core::run(server);
 /// }
 /// ```
-pub fn start<F: Future>(future: F) {
-    start_with_threads(future, num_cpus::get())
+pub fn run<F: Future>(future: F) {
+    run_with_threads(future, num_cpus::get())
 }
 
 /// If you don't want to include tokio in your project directly,
-/// you can use this function to start server.
+/// you can use this function to run server.
 /// ```ignore
 /// use salvo_core::prelude::*;
 /// #[fn_handler]
@@ -99,12 +103,12 @@ pub fn start<F: Future>(future: F) {
 ///     "Hello World"
 /// }
 /// fn main() {
-///    let service = Service::new(Router::new().get(hello_world));
-///    let server = Server::bind(&"127.0.0.1:7878".parse().unwrap()).serve(service);
-///    salvo_core::start_with_threads(server, 8);
+///    let service = Router::new().get(hello_world);
+///    let server = Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+///    salvo_core::run_with_threads(server, 8);
 /// }
 /// ```
-pub fn start_with_threads<F: Future>(future: F, threads: usize) {
+pub fn run_with_threads<F: Future>(future: F, threads: usize) {
     let runtime = crate::new_runtime(threads);
     let _ = runtime.block_on(async { future.await });
 }
